pub struct ContentEncryptionKey;Expand description
A content-encryption-key (CEK) - alternatively data-encryption-key (DEK) - a single-use symmetric key that encrypts content directly. It SHALL NOT be re-used for multiple encrypt operations.
See the key_hierarchy module documentation for its place in the key hierarchy.
Implementations
Sourceimpl ContentEncryptionKey
impl ContentEncryptionKey
Sourcepub fn make<Ids: KeySlotIds>(
ctx: &mut KeyStoreContext<'_, Ids>,
) -> Ids::Symmetric
pub fn make<Ids: KeySlotIds>( ctx: &mut KeyStoreContext<'_, Ids>, ) -> Ids::Symmetric
Generates a fresh content-encryption-key, stores it in the key store context, and returns its key id.
Sourcepub(crate) fn is_key_algorithm_valid<Ids: KeySlotIds>(
ctx: &KeyStoreContext<'_, Ids>,
key_id: Ids::Symmetric,
) -> bool
pub(crate) fn is_key_algorithm_valid<Ids: KeySlotIds>( ctx: &KeyStoreContext<'_, Ids>, key_id: Ids::Symmetric, ) -> bool
Returns whether the symmetric key key_id refers to uses an algorithm permitted for a
content-encryption-key. Returns false if the key is missing or uses an unsupported
algorithm.